@@ -4,7 +4,7 @@
 #
 #     This program is under GPL [http://www.gnu.org/copyleft/gpl.htm]
 #
-#     (c) 2000,2001,2002,2003,2004,2005 - Tom Eastep (teastep@shorewall.net)
+#     (c) 2000,2001,2002,2003,2004,2005,2006,2007 - Tom Eastep (teastep@shorewall.net)
 #
 #       Shorewall documentation is available at http://shorewall.net
 #
@@ -22,7 +22,7 @@
 #       Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
 #
 
-VERSION=3.2.6
+VERSION=3.4.4
 
 usage() # $1 = exit status
 {
@@ -187,17 +187,6 @@ DEBIAN=
 
 OWNERSHIP="-o $OWNER -g $GROUP"
 
-if [ -d /etc/apt -a -e /usr/bin/dpkg ]; then
-    DEBIAN=yes
-elif [ -f /etc/slackware-version ] ; then
-    DEST="/etc/rc.d"
-    INIT="rc.firewall"
-elif [ -f /etc/arch-release ] ; then
-      DEST="/etc/rc.d"
-      INIT="shorewall-lite"
-      ARCHLINUX=yes
-fi
-
 if [ -n "$PREFIX" ]; then
 	if [ `id -u` != 0 ] ; then
 	    echo "Not setting file owner/group permissions, not running as root."
@@ -206,6 +195,15 @@ if [ -n "$PREFIX" ]; then
 
 	install -d $OWNERSHIP -m 755 ${PREFIX}/sbin
 	install -d $OWNERSHIP -m 755 ${PREFIX}${DEST}
+elif [ -d /etc/apt -a -e /usr/bin/dpkg ]; then
+    DEBIAN=yes
+elif [ -f /etc/slackware-version ] ; then
+    DEST="/etc/rc.d"
+    INIT="rc.firewall"
+elif [ -f /etc/arch-release ] ; then
+      DEST="/etc/rc.d"
+      INIT="shorewall-lite"
+      ARCHLINUX=yes
 fi
 
 #
@@ -229,6 +227,8 @@ if [ -z "$PREFIX" -a -d /etc/shorewall-lite ]; then
 	backup_directory /usr/share/shorewall-lite
 	backup_directory /var/lib/shorewall-lite
     fi
+    [ -f /etc/shorewall-lite/shorewall.conf ] && \
+	mv -f /etc/shorewall-lite/shorewall.conf /etc/shorewall-lite/shorewall-lite.conf
 else
     first_install="Yes"
     rm -rf ${PREFIX}/etc/shorewall-lite
@@ -269,9 +269,9 @@ chmod 755 ${PREFIX}/usr/share/shorewall-lite
 #
 # Install the config file
 #
-if [ ! -f ${PREFIX}/etc/shorewall-lite/shorewall.conf ]; then
-   run_install $OWNERSHIP -m 0744 shorewall.conf ${PREFIX}/etc/shorewall-lite/shorewall.conf
-   echo "Config file installed as ${PREFIX}/etc/shorewall-lite/shorewall.conf"
+if [ ! -f ${PREFIX}/etc/shorewall-lite/shorewall-lite.conf ]; then
+   run_install $OWNERSHIP -m 0744 shorewall-lite.conf ${PREFIX}/etc/shorewall-lite/shorewall-lite.conf
+   echo "Config file installed as ${PREFIX}/etc/shorewall-lite/shorewall-lite.conf"
 fi
 
 if [ -n "$ARCHLINUX" ] ; then
@@ -291,12 +291,18 @@ install_file configpath ${PREFIX}/usr/share/shorewall-lite/configpath 0644
 echo "Default config path file installed as ${PREFIX}/usr/share/shorewall-lite/configpath"
 
 #
-# Install the functions file
+# Install the libraries
 #
+for f in lib.* ; do
+    if [ -f $f ]; then
+	install_file $f ${PREFIX}/usr/share/shorewall-lite/$f 0644
+	echo "Library ${f#*.} file installed as ${PREFIX}/usr/share/shorewall-lite/$f"
+    fi
+done
 
-install_file functions ${PREFIX}/usr/share/shorewall-lite/functions 0444
+ln -sf lib.base ${PREFIX}/usr/share/shorewall-lite/functions
 
-echo "Common functions installed in ${PREFIX}/usr/share/shorewall-lite/functions"
+echo "Common functions linked through ${PREFIX}/usr/share/shorewall-lite/functions"
 
 #
 # Install Shorecap
@@ -307,12 +313,14 @@ install_file shorecap ${PREFIX}/usr/share/shorewall-lite/shorecap 0555
 echo
 echo "Capability file builder installed in ${PREFIX}/usr/share/shorewall-lite/shorecap"
 
-
-# Install the Help file
 #
-install_file help ${PREFIX}/usr/share/shorewall-lite/help 0544
+# Install wait4ifup
+#
 
-echo "Help command executor installed in ${PREFIX}/usr/share/shorewall-lite/help"
+install_file wait4ifup ${PREFIX}/usr/share/shorewall-lite/wait4ifup 0555
+
+echo
+echo "wait4ifup installed in ${PREFIX}/usr/share/shorewall-lite/wait4ifup"
 
 #
 # Install the Modules file
@@ -320,6 +328,30 @@ echo "Help command executor installed in ${PREFIX}/usr/share/shorewall-lite/help
 run_install $OWNERSHIP -m 0600 modules ${PREFIX}/usr/share/shorewall-lite/modules
 echo "Modules file installed as ${PREFIX}/usr/share/shorewall-lite/modules"
 
+#
+# Install the Man Pages
+#
+
+cd manpages
+
+rm -f *.gz
+
+for f in *.5; do
+    gzip $f
+    run_install -D -m 444 $f.gz ${PREFIX}/usr/share/man/man5/$f.gz
+    echo "Man page $f.gz installed to /usr/share/man/man5/$f.gz"
+done
+
+for f in *.8; do
+    gzip $f
+    run_install -D -m 444 $f.gz ${PREFIX}/usr/share/man/man8/$f.gz
+    echo "Man page $f.gz installed to /usr/share/man/man8/$f.gz"
+done
+
+cd ..
+
+echo "Man Pages Installed"
+
 #
 # Create the version file
 #
